@@ -143,9 +143,7 @@ def get_length(arg):
         return total_length
     if isinstance(arg, astroid.nodes.Starred):
         base_length = 1 # '*'
-        total_length = 0
-        for value in arg.value:
-            total_length += get_length(value)
+        total_length = get_length(arg.value)
         total_length += base_length
         return total_length
     if isinstance(arg, astroid.nodes.Slice):
